//--------------------------------------------------------------------------//
//																			//
//	 Name: 	MEMS Mic interface to the ADSP-BF533 EZ-KIT Lite						//
//																			//
//--------------------------------------------------------------------------//
//																			//
//																				//
//	Project Name:	Two MEMS microphone Interface with Blackfin 								//
//																			//
//	Date Modified:	22/04/2010		Rev 0.1							//
//																			//
//	Software:		VisualDSP++ 5.0 update 7										//
//																			//
//	Hardware:		ADSP-BF533 EZ-KIT Board									//
//																			//
//	Connections:	         MICs                    			  Blackfin  



//                       1  -> L/R select    				 one to GND pin 3/4/87/88  of J2 connector of BF 533 EZ kit                 
//                                                           and other to Vdd pin 1/2/89/90  of J2	

//                       3  -> GND of both microphones		 GND pin 3/4/87/88  of J2


//                       4  ->Data of both microphones		 pin 29 of J2 connector of BF 533 EZ kit


//                       5  ->Vdd of both microphones 		 Vdd pin 1/2/89/90  of J2									//
//	-------------------------------------------------------------------------------------------------------					
//                       2  -> Clk of both microphones		 Extrenal source at 3.072 Mhz and connect the same to                    
//                                                           pin 31 of J2(SPORT FS) connector of BF 533 EZ kit

//                       Extrenal source at 6.144 Mhz        pin 33 of J2(SPORT clk) connector of BF 533 EZ kit

													//
//	Purpose:		This program sets up the SPI port on the ADSP-BF533 to  //
//					configure the AD1836 codec.  The SPI port is disabled 	//
//					after initialization.  The data from the microphone are taken from SPORT1					//
//					and inside the ISR of each descriptor the received PDM data is sent for 
//                  filtering :: 5th order CIC followed by FIR filters and sent out through DAC														//
//--------------------------------------------------------------------------//

#include "Talkthrough.h"
#include "sysreg.h"
#include "ccblkfn.h"
#include<cdefBF533.h>
#include<sys/exception.h>
#include<stdio.h>
#include "adi_ssl_init.h"
#include <fract.h>
#include <filter.h>
#include<cycle_count.h>
#include<12k_192khalfband.h>
#include<12k_384khalfband.h>
#include<16bit_6k_96kcoefs.h>

const char __argv_string[] = "-abc -xyz";

#define I2S_MODE

#define SELEN 0x0f

fract16 delay1_Left[NUM_TAPS1];

fir_state_fr16 state1_Left;


fract16 delay2_Left[NUM_TAPS2];

fir_state_fr16 state2_Left;


fract16 delay3_Left[NUM_TAPS3];

fir_state_fr16 state3_Left;


fract16 delay4_Left[NUM_TAPS4];

fir_state_fr16 state4_Left;


fract16 delay1_Right[NUM_TAPS1];

fir_state_fr16 state1_Right;


fract16 delay2_Right[NUM_TAPS2];

fir_state_fr16 state2_Right;


fract16 delay3_Right[NUM_TAPS3];

fir_state_fr16 state3_Right;


fract16 delay4_Right[NUM_TAPS4];

fir_state_fr16 state4_Right;

int var;

volatile short sCodec1836TxRegs[CODEC_1836_REGS_LENGTH] =
{									
					DAC_CONTROL_1	| 0x000,           // 16 bit data
					DAC_CONTROL_2	| 0x000,
					DAC_VOLUME_0	| 0x3ff,
					DAC_VOLUME_1	| 0x3ff,
					DAC_VOLUME_2	| 0x3ff,
					DAC_VOLUME_3	| 0x3ff,
					DAC_VOLUME_4	| 0x000,
					DAC_VOLUME_5	| 0x000,
					ADC_CONTROL_1	| 0x040,           //96kHz
					ADC_CONTROL_2	| 0x000,
					ADC_CONTROL_3	| 0x000
					
};


void main(void)
{
	long int i,j,k,l;
	int cycl[2];
	u32 cclk, sclk, vco;
	*pSIC_IMASK |= 0x1800;
	asm ("ssync;") ;
		
    	adi_ssl_Init();
     	adi_pwr_SetFreq(600000000,120000000, ADI_PWR_DF_NONE);
	//	adi_pwr_SetFreq(540000000,49090909, ADI_PWR_DF_NONE);	
		adi_pwr_GetFreq(&cclk,&sclk,&vco);
		asm("nop;nop;nop;nop;");
		printf("cclk = %d, sclk = %d, vco = %d\n", cclk, sclk, vco);
	
    var=2*Size/8;
	sysreg_write(reg_SYSCFG, 0x32);		//Initialize System Configuration Register
	Init_EBIU();
	Init_Flash();
	Init1836();
	Init_Sport0();
	Init_DMA();
	Init_Interrupts();
	
	
fir_init(state1_Left, coefs1, delay1_Left, NUM_TAPS1, 2);	// initialize filter state

fir_init(state1_Right, coefs1, delay1_Right, NUM_TAPS1, 2);	// initialize filter state
	
fir_init(state2_Left, coefs2, delay2_Left, NUM_TAPS2, 2);	// initialize filter state

fir_init(state2_Right, coefs2, delay2_Right, NUM_TAPS2, 2);	// initialize filter state

//fir_init(state3_Left, coefs3, delay3, NUM_TAPS3, 2);	// initialize filter state

fir_init(state4_Left, coefs4, delay4_Left, NUM_TAPS4, 1);	// initialize filter state

fir_init(state4_Right, coefs4, delay4_Right, NUM_TAPS4, 1);	// initialize filter state
	
	
	Enable_DMA_Sport0();
	

	while(1)
	{asm("nop;");
	}
}



